@@ -1,5 +1,6 @@
-from typing import Optional
+from typing import Optional, Union
 from fastapi_camelcase import CamelModel
+from telus_bulk.models.clli import Clli
 
 
 class ReportAddress(CamelModel):
@@ -11,7 +12,7 @@ class ReportAddress(CamelModel):
     best_offer: Optional[str] = ""
     speed: Optional[str] = ""
     technology: Optional[str] = ""
-    region_clli: Optional[str] = ""
+    region_clli: Optional[Clli | str] = None
     nearest_distance: Optional[str] = ""
     location_type: Optional[str] = ""
     comments: Optional[str] = ""
@@ -25,7 +26,7 @@ class ReportAddressUpdateDto(CamelModel):
     best_offer: Optional[str] = ""
     speed: Optional[str] = ""
     technology: Optional[str] = ""
-    region_clli: Optional[str] = ""
+    region_clli: Optional[Clli | str] = None
     nearest_distance: Optional[str] = ""
     location_type: Optional[str] = ""
     comments: Optional[str] = ""
